@@ -14,8 +14,9 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 from thbase.hbase import THBaseService
-from thbase.hbase.ttypes import TTableDescriptor
+from thbase.hbase.ttypes import TTableDescriptor, TPermissionScope
 from thbase.hbase.ttypes import TColumnFamilyDescriptor
+from thbase.hbase.ttypes import TAccessControlEntity
 from thbase.clientbase import ClientBase
 from thbase.thrift2.table import Table
 from thbase.util.executor import Executor
@@ -315,3 +316,41 @@ class Client(ClientBase):
         """
         type_check(table_descriptor, TTableDescriptor)
         return self.executor.call(lambda: self.client.modifyTable(table_descriptor))
+
+    def grant(self, info):
+        """
+
+        Args:
+            info:
+
+        Returns:
+
+        """
+        type_check(info, TAccessControlEntity)
+        return self.executor.call(lambda: self.client.grant(info))
+
+    def revoke(self, info):
+        """
+
+        Args:
+            info:
+
+        Returns:
+
+        """
+        type_check(info, TAccessControlEntity)
+        return self.executor.call(lambda: self.client.revoke(info))
+
+    def get_user_permissions(self, domain_name):
+        """
+
+        Args:
+            domain_name:
+            scope:
+
+        Returns:
+
+        """
+        type_check(domain_name, str)
+        scope = TPermissionScope.TABLE if domain_name[0] != '@' else TPermissionScope.NAMESPACE
+        return self.executor.call(lambda: self.client.getUserPermission(domain_name, scope))
