@@ -67,13 +67,11 @@ class ExceptionHandler(Observer):
                                                    " Client will resend the request.")
                         return True
                     else:
-                        logger.error(error_str + " The error cannot be solved by resending the request,"
-                                                 " client will shutdown.")
+                        logger.error(error_str + " The error cannot be solved by resend the request, client will shutdown.")
                         raise value
                 except AttributeError:
                     raise AttributeError("The IOError does not contain the canRetry mark. The error will be raised. "
                                          "Please check if the client version is too old.")
-
             if isinstance(value, TTransportException):
                 if value.type == TTransportException.NOT_OPEN or value.type == TTransportException.TIMED_OUT:
                     logger.warning("A transport error occurs, the message is: {}".format(value.message))
